from fastapi import APIRouter, Depends, status, HTTPException
from sqlalchemy.orm import Session
from core.database import get_db
from schemas.booking import BookingCreate, BookingResponse
from helpers.booking_helpers import create_booking

router = APIRouter()

@router.post("/booking", status_code=status.HTTP_201_CREATED, response_model=BookingResponse)
async def create_booking_endpoint(
    booking_data: BookingCreate,
    db: Session = Depends(get_db)
):
    """Endpoint for creating a new booking resource"""
    try:
        booking = create_booking(db=db, booking_data=booking_data)
        return booking
    except Exception as e:
        raise HTTPException(status_code=status.HTTP_400_BAD_REQUEST, detail=str(e))